package wekan.wrapper.api;

import retrofit2.Call;
import retrofit2.http.*;
import wekan.wrapper.entity.Checklist;
import wekan.wrapper.entity.ChecklistPrototype;

import java.util.List;

public interface ChecklistService {

    /**
     * Get all checklists attached on a card.
     *
     * @param boardId   The ID of the board
     * @param cardId    The ID of the card
     * @return  The list with the checklists
     */
    @GET("/api/boards/{boardId}/cards/{cardId}/checklists")
    Call<List<Checklist>> getChecklists(
            @Path("boardId") String boardId,
            @Path("cardId") String cardId
    );

    /**
     * Attach new empty checklist to a card.
     *
     * @param boardId   The ID of the board
     * @param cardId    The ID of the card
     * @param title     The title of the new checklist
     * @return  The new checklist
     */
    @FormUrlEncoded
    @POST("/api/boards/{boardId}/cards/{cardId}/checklists")
    Call<Checklist> postChecklist(
            @Path("boardId") String boardId,
            @Path("cardId") String cardId,
            @Field("title") String title
    );

    /**
     * Attach new checklist to a card.
     *
     * @param boardId               The ID of the board
     * @param cardId                The ID of the card
     * @param checklistPrototype    The prototype of the checklist
     * @return  The new checklist
     * @see ChecklistPrototype
     */
    @POST("/api/boards/{boardId}/cards/{cardId}/checklists")
    Call<Checklist> postChecklist(
            @Path("boardId") String boardId,
            @Path("cardId") String cardId,
            @Body ChecklistPrototype checklistPrototype
    );
}
